@@ -14,19 +14,23 @@ public:
     LatitudeGUI(QMainWindow *parent = 0);
 
 private slots:
-    void get();
-    void gsetOK();
-    void gsetERROR();
+    void get_loc();
+    void get_cell();
+    void get_gps();
     void set();
-    void showmap();
-    void showlat();
+    void set_OK();
+    void set_ERROR();
     void save();
+    void show_map();
+    void show_lat();
+    void maps_login();
 
 private:
     GoogleLatitude *glatitude;
     QSettings *setting;
     QWebView *maps;
     QWidget *location;
+    QUrl urllogin;
 
     QLineEdit *login_user;
     QLineEdit *login_pass;
@@ -34,10 +38,8 @@ private:
     QLineEdit *location_lon;
     QLineEdit *location_acc;
 
-    void do_maps();
     QFormLayout *do_login();
     QFormLayout *do_location();
-    void do_main();
 };
 
 #endif // LATITUDE_H
